@@ -1,6 +1,5 @@
 import json
-import re
-from typing import List, Optional, Tuple
+from typing import List, NamedTuple, Optional
 from urllib import parse
 from uuid import uuid4
 
@@ -31,7 +30,7 @@ class KeyQuerySet(models.QuerySet):
         return {"keys": [key.as_jwk() for key in self.active()]}
 
 
-class KeyManager(models.Manager):
+class BaseKeyManager(models.Manager):
     """Manager for Key objects."""
 
     def create_from_jwk(self, key):
@@ -59,6 +58,9 @@ class KeyManager(models.Manager):
         return self.create_from_jwk(JWK.generate(kty="RSA", size=2048))
 
 
+KeyManager = BaseKeyManager.from_queryset(KeyQuerySet)
+
+
 class Key(models.Model):
     """A keypair for use in LTI integrations.
 
@@ -76,7 +78,7 @@ class Key(models.Model):
     datetime_created = models.DateTimeField(_("created"), default=now, editable=False)
     datetime_modified = models.DateTimeField(_("modified"), auto_now=True)
 
-    objects = KeyManager.from_queryset(KeyQuerySet)()
+    objects = KeyManager()
 
     class Meta:
         verbose_name = _("JWK")
@@ -353,6 +355,8 @@ class LtiContext(models.Model):
 
     def update_memberships(self, member_data: List[dict]):
         """Updates memberships for this context using NRPS data."""
+        from .utils import normalize_role
+
         registration = self.deployment.registration
         for member in member_data:
             user_defaults = {
@@ -367,9 +371,7 @@ class LtiContext(models.Model):
                 sub=member["user_id"],
                 defaults={k: v for (k, v) in user_defaults.items() if v is not None},
             )
-            member_roles = [
-                LtiMembership.normalize_role(role) for role in member["roles"]
-            ]
+            member_roles = [normalize_role(role) for role in member["roles"]]
             LtiMembership.objects.update_or_create(
                 context=self,
                 user=user,
@@ -425,13 +427,6 @@ class LtiMembership(models.Model):
     def __str__(self):
         return f"{self.user} in {self.context}"
 
-    @classmethod
-    def normalize_role(cls, role: str) -> str:
-        """Expands a simple context role to a full URI, if needed."""
-        if re.match(r"^\w+$", role):
-            return f"http://purl.imsglobal.org/vocab/lis/v2/membership#{role}"
-        return role
-
 
 class LtiResourceLink(models.Model):
     """Represents a resource link in an LTI launch.
@@ -466,6 +461,11 @@ class LtiResourceLink(models.Model):
         return self.title if self.title else self.id_on_platform
 
 
+class ViewportDimensions(NamedTuple):
+    width: int
+    height: int
+
+
 class LtiLaunch:
     """A LTI launch."""
 
@@ -592,6 +592,7 @@ class LtiLaunch:
             user__registration__client_id=client_id,
             user__sub=sub,
             context__id_on_platform=context_id,
+            context__deployment=self.deployment,
         )
 
     @property
@@ -612,7 +613,7 @@ class LtiLaunch:
         return self.get_claim("https://purl.imsglobal.org/spec/lti/claim/tool_platform")
 
     @cached_property
-    def platform_instance(self) -> LtiPlatformInstance:
+    def platform_instance(self) -> Optional[LtiPlatformInstance]:
         if self.platform_instance_claim is None:
             return None
         return LtiPlatformInstance.objects.get(
@@ -629,19 +630,21 @@ class LtiLaunch:
     def document_target(self) -> Optional[str]:
         """The kind of browser window or frame in which the launch is presented.
 
-        See https://www.imsglobal.org/spec/lti/v1p3/#launch-presentation-claim"""
+        See https://www.imsglobal.org/spec/lti/v1p3/#launch-presentation-claim
+        """
         if self.launch_presentation_claim is None:
             return None
         return self.launch_presentation_claim.get("document_target")
 
     @property
-    def dimensions(self) -> Optional[Tuple[int, int]]:
+    def dimensions(self) -> Optional[ViewportDimensions]:
         """Width and height of the window or frame in which the launch is presented.
 
-        See https://www.imsglobal.org/spec/lti/v1p3/#launch-presentation-claim"""
+        See https://www.imsglobal.org/spec/lti/v1p3/#launch-presentation-claim
+        """
         if self.launch_presentation_claim is None:
             return None
-        dimensions = (
+        dimensions = ViewportDimensions(
             self.launch_presentation_claim.get("width"),
             self.launch_presentation_claim.get("height"),
         )
